
from django.db.models import Q
from uhepp_vault.models import PUBLIC_LEVEL, INTERNAL_LEVEL, PUBLIC_LEVEL, \
                               Collection

class BaseMaskingBackend:
    def __init__(self, orig_obj, view):
        self.orig_obj = orig_obj
        self.view = view

    def _has_mask(self, field):
        return hasattr(self, f"mask_{field}")

    def _get_mask(self, field):
        return getattr(self, f"mask_{field}")

    def __getattr__(self, key):
        orig_attr = getattr(self.orig_obj, key)
        if self._has_mask(key):
            mask = self._get_mask(key)
            return mask(orig_attr)
        return orig_attr

class MaskRelatedColletions(BaseMaskingBackend):
    def mask_collections(self, orig_collections):
        return filter_collections(orig_collections, self.view.request.user)

def filter_collections(queryset, user):
    if not user.is_authenticated:
        queryset = queryset.filter(
            visibility__gte=PUBLIC_LEVEL,
        )
    else:
        queryset = queryset.filter(
            Q(visibility__gte=INTERNAL_LEVEL) |
            Q(owner=user)
        )
    return queryset

